@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_service - remote control daemon for Nokia N900 phone#
-# $Id: smscon_service.py 141 2012-01-09 23:30:18Z yablacky $
+# $Id: smscon_service.py 150 2012-01-15 19:54:20Z yablacky $
 ##############################################################
 
 # standard modules
@@ -29,7 +29,8 @@ from email.MIMEMultipart import MIMEMultipart
 
 import smsconlib as smscon
 from smsconlib import InstPath, LogPath, PhotoName, MapName, AudioFile, DaemonFile, smscon_daemon
-from smsconlib import IF, IsHostReachable, IsInternetReachable, IsSamePhoneNumber, IsFileReadable, DeleteFile, shellArg, pidof, SendSMSviaGSMmodem
+from smsconlib import IF, IsHostReachable, IsInternetReachable, IsSamePhoneNumber, IsFileReadable, DeleteFile, \
+                        csvList, shellArg, pidof, SendSMSviaGSMmodem
 
 LOGGER = smscon.LOGGER = smscon.StartLogging('DAEMON', withConsole = False)
 
@@ -59,7 +60,7 @@ IsCheckHostActive           = False
 
 LastBatteryStatusMessage    = None
 
-CheckHostLastCommand        = '-1'      # "restart"
+CheckHostLastCommand        = '-1'      # almost COM_RESTART but special "restart"
 CheckHostStatusCount        = 0         # positive: successes, negative: errors
 CheckHostStatusTimestamp    = time.gmtime()
 
@@ -533,7 +534,8 @@ def ProcessCommand(Command, SenderPhoneNumber=None, CommandOrigin=None, ExtraInf
     else:
         CommandOrigin = str(CommandOrigin)
 
-    LOGGER.info('Received %s command [%s] via %s %s.' % (smscon.NAME, Command, CommandOrigin, ExtraInfo))
+    LOGGER.info('Received %s command [%s] via %s %s. Acknowledge message %s.' % (smscon.NAME, Command, CommandOrigin, ExtraInfo,
+                    IF(smscnf.COMMANDREPLY == 'yes', 'enabled', 'disabled')))
     LogBatteryChargeInfo()
 
     # First of all, make phone silent
@@ -542,8 +544,6 @@ def ProcessCommand(Command, SenderPhoneNumber=None, CommandOrigin=None, ExtraInf
     # Command reply
     if smscnf.COMMANDREPLY == 'yes':
         RevealThat('reply', 'Command (%s) accepted.' % Command)
-    else:
-        LOGGER.info('Command (%s) accepted. Acknowledge message disabled.' % Command)
 
     # Explicit device locking
     if Command == smscnf.COM_UNLOCK:
@@ -648,7 +648,7 @@ def ProcessCommand(Command, SenderPhoneNumber=None, CommandOrigin=None, ExtraInf
         RestartDaemon()
 
     else:
-        LOGGER.debug('Unknown command: [%s].' % Command)
+        LOGGER.debug('Ignoring unknown command: [%s].' % Command)
 
 #############################################
 #   play sound file as an alarm
@@ -694,8 +694,8 @@ def PerformAlarm():
     LOGGER.info('(ALARM) current profile is "%s".' % CurrentProfile)
     if CurrentProfile != 'general':
         LOGGER.info('(ALARM) Set phone profile temporarily to "General" for alarm.')
-        PrePlayCommand.append(SetPhoneProfileCommand % shellArg('general'))
-        RestoreProfileCommand.append(SetPhoneProfileCommand % shellArg(CurrentProfile))
+        PrePlayCommand .append(SetPhoneProfileCommand % shellArg('general'))
+        PostPlayCommand.append(SetPhoneProfileCommand % shellArg(CurrentProfile))
 
     # set volume to maximum
     Volume = 100
@@ -1498,6 +1498,7 @@ def OnGPSchanged(GpsDevice, GpsData):
     global GpsCoordinateList
     global GpsStartTime
 
+    LOGGER.debug('OnGPSchanged() called for mode "%s".' % str(GpsMode))
     if not GpsMode:
         return
 
@@ -1535,6 +1536,7 @@ def OnGPSchanged(GpsDevice, GpsData):
             RevealThat('GPS', 'GPS device timeout after %.1f sec.' % TimePassedSeconds, smscnf.GPSSEND)                    
             # stop the GPS device
             GpsData.stop()
+        LOGGER.debug('GpsData not OK after %.1f sec.' % TimePassedSeconds)
         return
 
     # Now we have really data, adjust timeout timer
@@ -1547,8 +1549,12 @@ def OnGPSchanged(GpsDevice, GpsData):
         GpsCoordinateList.append( (Latitude, Longitude, Accuracy) )
         LOGGER.info( 'GPS coordinate #%d acquired (%f, %f, %.1f m.).'
                         % (len(GpsCoordinateList), Latitude, Longitude, Accuracy) )                
-        if len(GpsCoordinateList) < int(smscnf.GPSPOLLING):
+        # We will dismiss the 1st received coordinate because this might be just the
+        # last coordinate from last long-time-ago fix and has nothing to do with
+        # current position. So effectively accuire one more coordinate than specified:  
+        if len(GpsCoordinateList) < int(smscnf.GPSPOLLING) + 1:
             return
+        GpsCoordinateList[0:1] = []     # Dismiss the 1st received coordinate. See comment above.
         # sort GPS coordinate list on 'Accuracy'
         GpsCoordinateList = sorted( GpsCoordinateList, key=itemgetter(2) )
         Latitude, Longitude, Accuracy = GpsCoordinateList[0]
@@ -1972,7 +1978,7 @@ def PerformCheckHost(CheckHostURL):
         UrlFile.close()
     except Exception, e:
         if CheckHostStatusCount >= 0:
-            LOGGER.error('(CHECKHOST) After %s: Failed to read remote file: %s' % (eventsOf('OK'), e))
+            LOGGER.error('(CHECKHOST) After %s: Failed to read remote command: %s' % (eventsOf('OK'), e))
             CheckHostStatusCount = 0
             CheckHostStatusTimestamp = time.gmtime()
         CheckHostStatusCount -= 1
@@ -1981,33 +1987,37 @@ def PerformCheckHost(CheckHostURL):
         return True
 
     if CheckHostStatusCount <= 0:
-        LOGGER.info('(CHECKHOST) After %s: Successfully read remote file.' % eventsOf('errors'))
+        LOGGER.info('(CHECKHOST) After %s: Successfully read remote command.' % eventsOf('errors'))
         CheckHostStatusCount = 0
         CheckHostStatusTimestamp = time.gmtime()
     CheckHostStatusCount += 1
 
+    # No longer treat '17' and '-1' differently. Map regular COM_RESTART to
+    # our special -1 so that we can handle it and not ProcessCommand():
+    if Command == '17': Command = '-1'
+
     LOGGER.debug('(CHECKHOST) Got command "%s". Last command was "%s".' % (Command, CheckHostLastCommand))
     if CheckHostLastCommand == Command:
         return True
     CheckHostLastCommand = Command
-    
+
     if Command in CommandList:
         Command = CommandList[Command]
-        LOGGER.info( '(CHECKHOST) %s is activated (command "%s") by remote host file.' % (DaemonFile, Command) )
+        LOGGER.info( '(CHECKHOST) Activating %s by remote command [%s].' % (DaemonFile, Command) )
         ProcessCommand(Command, CommandOrigin = 'CHECKHOST', ExtraInfo = CheckHostURL)
 
     elif Command == '00':
-        LOGGER.info( '(CHECKHOST) %s is deactivated (%s) by remote host file.' % (DaemonFile, Command) )
+        LOGGER.info( '(CHECKHOST) Leave %s idle by remote command [%s].' % (DaemonFile, Command) )
 
     elif Command == '-1':
-        LOGGER.info( '(CHECKHOST) %s will restart (%s) by remote host file.' % (DaemonFile, Command) )
+        LOGGER.info( '(CHECKHOST) Will restart %s by remote command [%s].' % (DaemonFile, Command) )
         try:
             os.system( '"%s" -restart' % os.path.join(InstPath, smscon.NAME) )
-        except:
-            LOGGER.error('(CHECKHOST) Failed to kill %s' % DaemonFile)
+        except Exception, e:
+            LOGGER.error('(CHECKHOST) Failed to kill %s: [%s]' % (DaemonFile, e))
     
     else:
-        LOGGER.error( '(CHECKHOST) %s unknown command (%s) by remote host file.' % (DaemonFile, Command) )
+        LOGGER.error( '(CHECKHOST) Ignoring unknown remote command [%s].' % (Command) )
 
     return True # run it continiously
 
@@ -2108,6 +2118,8 @@ def LoadConfiguration():
             return False
         theConf.upgrade(Permanent = False)  # Only in RAM; Do not change last known good on disk.
 
+    smscon.EnableDebugLogging(theConf)
+
     # For convinience code make config settings available as attributes:
     for key in theConf.getKnownConfigVars():
         if not key in theConf:
