@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon - remote control library for Nokia N900 phone       #
-# $Id: smsconlib.py 145 2012-01-11 00:43:24Z yablacky $
+# $Id: smsconlib.py 150 2012-01-15 19:54:20Z yablacky $
 ##############################################################
 
 # standard modules
@@ -34,7 +34,7 @@ NAME = 'smscon'
 VERSION = '999.1'   # for trunk and private builds etc.
 
 NAME, VERSION = getSysBuildNameAndVersion(NAME, VERSION,
-    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.13/src/opt/smscon/smsconlib.py 145 2012-01-11 00:43:24Z yablacky $',
+    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.14/src/opt/smscon/smsconlib.py 150 2012-01-15 19:54:20Z yablacky $',
     dirLevels   = 3 )
     
 XDEBUG   = False        # cross debug (use only if not running on phone)
@@ -121,6 +121,13 @@ def commonPrefix(*args):
     if len(args):   return args[0]
     else:           return ''
 
+def csvList(s):
+    """
+    @param string s A comma separated value.
+    @return list of trimmed strings extracted from comma separated value s.
+    """
+    return map(lambda s: s.strip(), s.split(','))
+    
 def shellArg(s):
     """@return string The parameter s quoted to be safely used as a shell parameter."""
     return "'%s'" % str(s).replace("\'", "'\"'\"'")
@@ -815,6 +822,7 @@ class UserConfiguration(Configuration):
         'SILENCEDEVICE':    (_BoolPattern,      'no',               _OPT_PLAIN, '# Set phone silent before executing command (yes|no):'),
         'AUTODEVICELOCK':   (_BoolPattern,      'no',               _OPT_PLAIN, '# Lock phone before executing any command except un/lock (yes|no):'),
         'SIMUNLOCK':        (_BoolPattern,      'no',               _OPT_PLAIN, '# Automatically unlock phone when new SIM is inserted (yes|no):'),
+        'DEBUGFLAGS':       ('',                '',                 _OPT_PLAIN, '# A csv with debugging options (for development use only)'),
     
         # Sensor detections
         'KEYBOARDDETECT':   (_BoolPattern,      'no',               _OPT_PLAIN, '# Send notification if keyboard is sliding (yes|no):'),
@@ -1274,13 +1282,13 @@ def StartLogging(instanceName, logLevel = None, withConsole = True, withEmitterF
     if os.geteuid() == 0:
         setattr(logger, 'LogFilename', os.path.join(LogPath, LogFile))
         fh = logging.FileHandler(logger.LogFilename)
-        fh.setLevel(logLevel)
+#        fh.setLevel(logLevel)            -- NO! dynamically inherit logLevel from parent
         fh.setFormatter(logging.Formatter('%(asctime)s[%(name)s] %(levelname)s: %(message)s', datefmt = TimeFormat))
         logger.addHandler(fh)
 
     if withConsole:
         ch = logging.StreamHandler()
-        ch.setLevel(logging.INFO)
+#        ch.setLevel(logging.INFO)        -- NO! dynamically inherit logLevel from parent
         ch.setFormatter(logging.Formatter('%(levelname)s: %(message)s'))
         logger.addHandler(ch)
 
@@ -1303,7 +1311,25 @@ def StartLogging(instanceName, logLevel = None, withConsole = True, withEmitterF
         LOGGER = logger
 
     return logger
-    
+
+def EnableDebugLogging(userConfig = None, enableDebugLogging = True):
+    """
+    Enable or disable debug logging for the current global logger, if any.
+    @param UserConfiguration userConfig with info about logging flags.
+    @param bool enableDebugLogging Indicates to enable or disable debug logging.
+    @return void.
+    """
+    global LOGGER
+    if not LOGGER or not userConfig:
+        return
+
+    if not getattr(userConfig, 'DEBUGFLAGS', None):
+           setattr(userConfig, 'DEBUGFLAGS', userConfig.get('DEBUGFLAGS', '').upper())
+
+    if LOGGER.name in csvList(userConfig.DEBUGFLAGS) or '*' in csvList(userConfig.DEBUGFLAGS):
+        LOGGER.setLevel(IF(enableDebugLogging, logging.DEBUG, logging.INFO))
+        LOGGER.debug("Debug logging "+IF(enableDebugLogging,'enabled.','disabled.'))
+
 ##############################################################
 
 if __name__ == "__main__":
